:program:`calorine`
*******************

:program:`calorine` is a small Python module for managing `GPUMD <https://gpumd.zheyongfan.org/>`_ simulations.
It provides an ASE calculator, IO functions for reading and writing :program:`GPUMD` input and output files, as well as a Python interface that allows extraction of NEP descriptors for a given atomic structure and calculation of energies and forces from Python.


.. toctree::
   :maxdepth: 2
   :caption: Main

   installation

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/gpunep_calculator
   tutorials/nepy

.. toctree::
   :maxdepth: 2
   :caption: Function reference

   calculator
   io
   analysis
   nepy
